#!/usr/bin/env python3
#-*- coding: iso-8859-15 -*-

##----------------------------------------------------------------------------------------------
## Coban - Module de calcul de chute de tension
## Copyright 2008-2010  Stphan GURIN
## contact : setthe@gmail.com
##
## Ce logiciel est un programme informatique destin aux lectriciens et 
## permettant de calculer rapidement la section d'un cble, de raliser des
## conversions d'units lectriques, etc.... 
##
## Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
## respectant les principes de diffusion des logiciels libres. Vous pouvez
## utiliser, modifier et/ou redistribuer ce programme sous les conditions
## de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
## sur le site "http://www.cecill.info".
##
## En contrepartie de l'accessibilit au code source et des droits de copie,
## de modification et de redistribution accords par cette licence, il n'est
## offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
## seule une responsabilit restreinte pse sur l'auteur du programme,  le
## titulaire des droits patrimoniaux et les concdants successifs.
##
## A cet gard  l'attention de l'utilisateur est attire sur les risques
## associs au chargement,   l'utilisation,   la modification et/ou au
## dveloppement et  la reproduction du logiciel par l'utilisateur tant 
## donn sa spcificit de logiciel libre, qui peut le rendre complexe  
## manipuler et qui le rserve donc  des dveloppeurs et des professionnels
## avertis possdant  des  connaissances  informatiques approfondies.  Les
## utilisateurs sont donc invits  charger  et  tester  l'adquation  du
## logiciel  leurs besoins dans des conditions permettant d'assurer la
## scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
##  l'utiliser et l'exploiter dans les mmes conditions de scurit. 
##
## Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
## pris connaissance de la licence CeCILL, et que vous en avez accept les
## termes.
##
##----------------------------------------------------------------------------------------------

############################################################################
##                                                                        ##
##                         Module "Voltage drop"                          ##
##                                                                        ##
##                                                                        ##
############################################################################

import wx

version = 'Voltage drop 0.2.3'
sectCu = '0.5 0.75 1 1.5 2.5 4 6 10 16 25  35 50 70 95 120 150 185 240 300 400 500 630'.split()
sectAlu = '10 16 25 35 50 70 95 120 150 185 240 300 400 630'.split()
statusText = u"Voltage drop"

      

class ModuleChute(wx.Frame):
    """Calculate cable cross-sections"""
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, -1, title = version,
                      style=wx.DEFAULT_FRAME_STYLE 
                      ^(wx.RESIZE_BORDER | wx.MAXIMIZE_BOX))
        self.parent = parent
        
        #------- Cration du panel -----------------------        
        panel =  wx.Panel(self, -1, style = wx.TAB_TRAVERSAL
                     | wx.CLIP_CHILDREN
                     | wx.FULL_REPAINT_ON_RESIZE
                     )
        
        #---------- cration du sizer principal ----------------
        
        self.gbs = wx.GridBagSizer(hgap=5, vgap=5)
        
        #------- Cration de statusbar -----------------        
        self.CreateStatusBar()
        self.SetStatusText(statusText)
        
        #---- Cration de la barre d'outils (toolbar) ---------------------------------------------------

        #-------------- import des images ----------------------
        
        from modcoban import bmp_aide, bmp_quit
        
        img_aide = wx.Bitmap(bmp_aide, wx.BITMAP_TYPE_PNG)
        img_quit = wx.Bitmap(bmp_quit, wx.BITMAP_TYPE_PNG)
        
        self.tbar = wx.ToolBar(self, -1, style= wx.TB_HORIZONTAL)
        # Hack pour windows :
        # ajustement de la taille des boutons aux images (24x24 px):
        self.tbar.SetToolBitmapSize((24,24))
        
        self.tbar.AddSimpleTool(90, 
                                img_aide,
                                shortHelpString = u"Help",
                                longHelpString = u"Max. values of voltage drop")
        self.tbar.AddSeparator()
        self.tbar.AddSimpleTool(99, 
                           img_quit,
                           shortHelpString = "Quit",
                           longHelpString = "Quit this module")
        self.tbar.Realize()
        self.SetToolBar(self.tbar)
        
        
        
        #------------- Cration des widgets ---------------------
        # Mono / Tri
        listeCircuit=[u'single phase', u'threephase']
        labelMonoTri = wx.StaticText(panel, -1, u'Type of circuit')
        self.monoTri = wx.Choice(panel, -1, choices=listeCircuit)
        self.monoTri.SetSelection(1)
        self.monoTri.SetFocus()
        self.labelCosPhi = wx.StaticText(panel, -1, u'cos Phi = 0,8')
        # type de cble :
        listeCable = ['Copper', 'Aluminium']
        labelCable = wx.StaticText(panel, -1, u"Cable-Type")
        self.cable = wx.Choice(panel, -1, choices=listeCable)
        self.cable.SetSelection(0)
        # Longueur du cble
        labelLg = wx.StaticText(panel, -1, u'Cable-length\n(meters) :')
        self.lg = wx.SpinCtrl(panel, -1, "", size=self.cable.GetSize())
        self.lg.SetRange(1, 999)
        self.lg.SetValue(100)
        # Section du conducteur
        labelSection = wx.StaticText(panel, -1, u'cross-section of conductor\n (mm)')
        self.section = wx.Choice(panel, -1, choices=sectCu, size=self.cable.GetSize())
        self.section.SetSelection(6)
        # Courant d'emploi
        labelCourant = wx.StaticText(panel, -1, u"Operating current\n(Ampere)")
        self.courant = wx.SpinCtrl(panel, -1, "", size=self.cable.GetSize())
        self.courant.SetRange(1,999)
        self.courant.SetValue(100)
        # Tension Ph/N
        labelTension = wx.StaticText(panel, -1, u'Voltage between phases\nand neutral (Volt)')
        listeTension = ['12V', '24V', '48V', '110V', '220V', '230V', '240V', '380V', '400V', '440V']
        self.tension = wx.Choice(panel, -1, choices=listeTension, size=self.cable.GetSize())
        self.tension.SetSelection(8)
        # Bouton calcul
        self.btnCalc = wx.Button(panel, -1, 'Calculate')
        self.btnCalc.SetBackgroundColour('yellow')
        self.btnCalc.SetDefault()
        if self.parent.licence_ok == 0:
            self.btnCalc.Enable(False)
        # Sparation
        sep = wx.BoxSizer(wx.VERTICAL)
        sep.Add(wx.StaticLine(panel), 0, wx.EXPAND|wx.ALL, 5)
        # Rsultats
        labelResult = wx.StaticText(panel, -1, u'Results')
        labelResult.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelChuteDelta=wx.StaticText(panel, -1, u'Voltage drop\n(in %)')
        self.labelDeltaU = wx.StaticText(panel, -1, u'... %')
        self.labelDeltaU.SetForegroundColour('blue')
        self.labelDeltaU.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelChuteV = wx.StaticText(panel, -1, u'Voltage drop\n(in Volts)')
        self.labelChuteVolt = wx.StaticText(panel, -1, u'... V')
        self.labelChuteVolt.SetForegroundColour('blue')
        self.labelChuteVolt.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        #------------------ binds ------------------------------
        self.Bind(wx.EVT_CHOICE, self.onSection, self.cable)
        #self.Bind(wx.EVT_CHOICE, self.onRaz, id=wx.ID_ANY)
        self.Bind(wx.EVT_SPINCTRL, self.onRaz)
        self.Bind(wx.EVT_BUTTON, self.onCalcul, self.btnCalc)
        self.Bind(wx.EVT_TOOL, self.onAide, id=90)
        self.Bind(wx.EVT_CLOSE, self.onQuitter)
        self.Bind(wx.EVT_TOOL, self.onQuitter, id=99)
        
        #---------------- placement of widgets ------------------
        self.gbs.Add(labelMonoTri, (0,0))
        self.gbs.Add(self.monoTri, (0,1))
        self.gbs.Add(self.labelCosPhi, (0,2))
        self.gbs.Add(labelCable, (1,0))
        self.gbs.Add(self.cable, (1,1))
        self.gbs.Add(labelLg, (2,0))
        self.gbs.Add(self.lg, (2,1))
        self.gbs.Add(labelSection, (3,0))
        self.gbs.Add(self.section, (3,1))
        self.gbs.Add(labelCourant, (4,0))
        self.gbs.Add(self.courant, (4,1))
        self.gbs.Add(labelTension, (5,0))
        self.gbs.Add(self.tension, (5,1))
        self.gbs.Add(self.btnCalc, (6,2))
        self.gbs.Add(sep, (7,0), (1,4),wx.EXPAND)
        self.gbs.Add(labelResult, (8,0))
        self.gbs.Add(labelChuteDelta, (9,0))
        self.gbs.Add(self.labelDeltaU, (9,1))
        self.gbs.Add(labelChuteV, (10,0))
        self.gbs.Add(self.labelChuteVolt, (10,1))
                
        #-------- rglage de la taille ---------------------------
        panel.SetSizerAndFit(self.gbs)
        self.SetClientSize(panel.GetSize())
        
        
    def onSection(self, evt):
        if self.cable.GetSelection() == 0 :
            self.section.SetItems(sectCu)
            self.section.SetSelection(6)
        else :
            self.section.SetItems(sectAlu)
            self.section.SetSelection(0)
        
        
        self.onRaz(self)
        
        
        
    def onAide(self, evt):
        msgAide = (u'Power supply between branch circuit breaker and distribution board:\n'
                   u'  - maximum Voltage drop : 2%\n\n'
                   u'Installations supplied directly from a low-voltage '
                   u'public distribution network:\n'
                   u'  - Lighting : 3 % max\n'
                   u'  - Other usages : 5 % max\n\n'
                   u'Installations supplied from a HV/LV substation:\n'
                   u'  - Lighting : 6 % max\n'
                   u'  - Other usages : 8 % max'
                   )

        dlg = wx.MessageDialog(self, msgAide,
                               u'Memo Voltage drop',
                               wx.OK | wx.ICON_INFORMATION
                               #wx.YES_NO | wx.NO_DEFAULT | wx.CANCEL | wx.ICON_INFORMATION
                               )
        dlg.ShowModal()
        dlg.Destroy()
        
    
        
    def onRaz(self, evt):
        self.labelChuteVolt.SetLabel('... V')
        self.labelDeltaU.SetLabel('... %')
        if self.monoTri.GetSelection() == 0:
            self.labelCosPhi.SetLabel(u'')
        else :
            self.labelCosPhi.SetLabel(u'cos Phi = 0,8')
            
        
    def onCalcul(self, evt):
        # import si mono ou tri
        if self.monoTri.GetSelection()==0:
            b = 2
            cosPhi = 1
            sinPhi = 1
        else : 
            b = 1
            cosPhi = 0.8
            sinPhi = 0.6
        # import de la rsistivit
        if self.cable.GetSelection() <= 3:
            rau1 = 23
        else :
            rau1 = 37
        # import de la longueur
        L = self.lg.GetValue()
        # import de la section
        S = float(self.section.GetStringSelection())
        # import du courant d'emploi
        Ib = self.courant.GetValue()
        # import de la tension
        if self.tension.GetSelection() == 0:
            Uo = 12
        elif self.tension.GetSelection() == 1:
            Uo = 24
        elif self.tension.GetSelection() == 2:
            Uo = 48
        elif self.tension.GetSelection() == 3:
            Uo = 110
        elif self.tension.GetSelection() == 4:
            Uo = 220
        elif self.tension.GetSelection() == 5:
            Uo = 230
        elif self.tension.GetSelection() == 6:
            Uo = 240
        elif self.tension.GetSelection() == 7:
            Uo = 380
        elif self.tension.GetSelection() == 8:
            Uo = 400
        else :
            Uo = 440
        # coef lambda
        Lambda = 0.08
        
        # rsultats
        u = round((b*(rau1*(L/S)*cosPhi+Lambda*L*sinPhi)*Ib)/1000, 3)
        deltaU = round((100*(u/Uo)), 2)
        self.labelChuteVolt.SetLabel(u'%s V'%u)
        self.labelDeltaU.SetLabel((u'%s '%deltaU)+'%')
    
    def onQuitter(self, evt):
        """Quit application"""
        self.parent.btnChute.Enable(True)
        self.parent.menuModuleChute.Enable(True)
        self.Destroy()
